function [data, chans] = fetch_data(ifo_name, t0, dt)
  % fetch data for use in sim_H1_ER8
  % t0 = 1126259462;
  
  % LSC, OMC and CAL channels
  chans_lsc = {'OMC-DCPD_A_OUT', 'OMC-DCPD_B_OUT', ...
    'OMC-DCPD_NULL_OUT', 'OMC-DCPD_SUM_OUT', ...
    'LSC-DARM_IN1', 'LSC-DARM_OUT', 'LSC-MICH_OUT', 'LSC-SRCL_OUT', ...
    'CAL-DELTAL_RESIDUAL', 'CAL-DELTAL_CTRL', 'CAL-DELTAL_EXTERNAL', ...
    'CAL-INJ_HARDWARE_OUT', 'CAL-INJ_BLIND_OUT'};
    
  % SUS-{I, E}TM{X, Y}_
  chans_tm = { ...
    'L1_LOCK_L_IN1', 'L1_LOCK_L_OUT', ...
    'L1_MASTER_OUT_LL', 'L1_MASTER_OUT_LR', ...
    'L1_MASTER_OUT_UL', 'L1_MASTER_OUT_UR', ...
    'L1_NOISEMON_LL', 'L1_NOISEMON_LR', ...
    'L1_NOISEMON_UL', 'L1_NOISEMON_UR', ...
    'L2_LOCK_L_IN1', 'L2_LOCK_L_OUT', ...
    'L2_MASTER_OUT_LL', 'L2_MASTER_OUT_LR', ...
    'L2_MASTER_OUT_UL', 'L2_MASTER_OUT_UR', ...
    'L2_NOISEMON_LL', 'L2_NOISEMON_LR', ...
    'L2_NOISEMON_UL', 'L2_NOISEMON_UR', ...
    'L3_ISCINF_L_IN1', 'L3_LOCK_L_IN1', 'L3_LOCK_L_OUT', ...
    'L3_MASTER_OUT_LL', 'L3_MASTER_OUT_LR', ...
    'L3_MASTER_OUT_UL', 'L3_MASTER_OUT_UR', ...
    'L3_LVESDAMON_LL', 'L3_LVESDAMON_LR', ...
    'L3_LVESDAMON_UL', 'L3_LVESDAMON_UR'};
  
  % ETMs
  chans_etmxy = [strcat('SUS-ETMX_', chans_tm), ...
    strcat('SUS-ETMY_', chans_tm)];
  
  % CAL-PCAL{X, Y}_
  chans_pcal = {'EXC_SUM', 'RX_PD_OUT', 'TX_PD_OUT'};
  chans_pcalxy = [strcat('CAL-PCALX_', chans_pcal), ...
    strcat('CAL-PCALY_', chans_pcal)];
    
  % build full channel list
  chans = [chans_lsc, chans_etmxy, chans_pcalxy];
  channel_list = strcat([ifo_name ':'], chans);
  channel_list = strcat(channel_list, '_DQ');
  
  % get the data
  gwd = GWData;
  if strcmp(ifo_name, 'L1')
    % L1 not working as well as H1
    gwd.site_info(1).server = 'nds2.ligo.caltech.edu';
    nrem = [matchstr(chans, 'SUS-ETMX_L1_LOCK_L_OUT'), ...
      matchstr(chans, 'SUS-ETMX_L2_LOCK_L_OUT'), ...
      matchstr(chans, 'SUS-ETMX_L3_LOCK_L_OUT'), ...
      matchstr(chans, 'SUS-ETMY_L1_LOCK_L_OUT'), ...
      matchstr(chans, 'SUS-ETMY_L2_LOCK_L_OUT'), ...
      matchstr(chans, 'SUS-ETMY_L3_LOCK_L_OUT')];
    nkeep = setdiff(1:numel(chans), nrem);
    chans = chans(nkeep);
    channel_list = channel_list(nkeep);
  end
  data = gwd.fetch(t0, dt, channel_list, 'mDV');
end
