function mtrx = measure_gains(data_st, filts, mtrx)
  % measure some "complicated gain factors" which come from
  % the linearization of OMC DC and ESD
  
  mtrx.g_SUM_DARM = gestimate(data_st.DCPD_SUM_OUT, ...
    data_st.DARM_IN1, data_st.fs, mtrx.LSC_ARM_INPUT_MTRX_1_1);
  
  
  mtrx.g_ETMY_L3 = gestimate(data_st.ETMY_L3_LOCK_L_OUT, ...
    data_st.ETMY_L3_MASTER_OUT_LL, data_st.fs, ...
    filts.SUS_ETMY_L3_DRIVEALIGN_L2L * filts.SUS_ETMY_L3_ESDOUTF_LL * ...
    mtrx.SUS_ETMY_L3_EUL2ESD_1_1);
  
end

function g = gestimate(a, b, fs, rel_tf)
  tfft = 0.5;
  nfft = round(tfft * fs);
  [hab, ff] = tfestimate(a, b, hann(nfft), [], nfft, fs);
  cab = mscohere(a, b, hann(nfft), [], nfft, fs);
  
  if isa(rel_tf, 'GWFilt')
    rel_tf = rel_tf.respz(ff);
  end
  hab = hab ./ rel_tf;
  
  % compute the gain
  g = mean(real(hab(cab > 0.998 & ff > 10 & ff < 800)));
  
  % do some cross-checks
  ga = mean(abs(hab(cab > 0.998 & ff > 10 & ff < 800)));
  stda = std(abs(hab(cab > 0.998 & ff > 10 & ff < 800)));
  
  if abs(log(abs(g / ga))) > 0.01
    warning('gain has some imaginary component (g / ga = %.3f )', g / ga)
  end
  if (stda / ga) > 0.01
    warning('gain is not constant (stda / ga = %.3f )', stda / ga)
    subplot(2, 1, 1)
    loglog(ff, [abs(real(hab)), abs(hab)]);
    grid on
    subplot(2, 1, 2)
    semilogx(ff, cab);
    grid on
    pause
  end
end